﻿using System;
using System.Drawing;
using System.Web;
using System.Drawing.Imaging;
using Telerik.Web.UI;

namespace CustomNameSpace
{
	public class CaptchaImageHandler : IHttpHandler, System.Web.SessionState.IRequiresSessionState
	{
		/// <summary>
		/// Enables processing of HTTP Web requests by a custom HttpHandler that implements the <see cref="T:System.Web.IHttpHandler"></see> interface.
		/// </summary>
		/// <param name="context">An <see cref="T:System.Web.HttpContext"></see> object that provides references to the intrinsic server objects (for example, Request, Response, Session, and Server) used to service HTTP requests.</param>
		public void ProcessRequest(HttpContext context)
		{
			HttpApplication app = context.ApplicationInstance;

			CaptchaImage ci = null;
			try
			{
				ci = (CaptchaImage)HttpContext.Current.Session["CaptchaImage"];
			}
			catch
			{
				app.Response.StatusCode = 404;
				context.ApplicationInstance.CompleteRequest();
				return;
			}

			// write the image to the HTTP output stream as an array of bytes
			// if there is no image available (we are in design mode) then draw
			// an empty one
			if (ci == null)
			{
				// define a gray brush and fill a graphic with it
				Brush brush = Brushes.Gray;
				Bitmap bitmap = new Bitmap(50, 50);
				Graphics graphic = Graphics.FromImage(bitmap);
				GraphicsUnit graphicsUnit = GraphicsUnit.Pixel;
				graphic.FillRectangle(brush, bitmap.GetBounds(ref graphicsUnit));

				// output the gray graphic
				bitmap.Save(app.Context.Response.OutputStream, ImageFormat.Gif);
				bitmap.Dispose();
				app.Response.ContentType = "image/gif";
			}
			else
			{
				Bitmap b = ci.RenderImage();
				b.Save(app.Context.Response.OutputStream, ImageFormat.Jpeg);
				b.Dispose();
				app.Response.ContentType = "image/jpeg";
			}
			app.Response.StatusCode = 200;
			context.ApplicationInstance.CompleteRequest();
		}

		/// <summary>
		/// Gets a value indicating whether another request can use the <see cref="T:System.Web.IHttpHandler"></see> instance.
		/// </summary>
		/// <value></value>
		/// <returns>true if the <see cref="T:System.Web.IHttpHandler"></see> instance is reusable; otherwise, false.</returns>
		public bool IsReusable
		{
			get
			{
				return true;
			}
		}
	}
}
